#include  "CreEPS.hpp"
#include  <math.h>

/******************************************************
 *
 *  This program creates all the graphics in the
 *  documentation of CreEPS in the current directory.
 *
 ******************************************************
 *
 * Uwe Fabricius : http://uwefabricius.de/
 * Thomas Pohl   : http://thomas-pohl.info/
 * 
 * Copyright (c) 2002 - 2009  Uwe Fabricius, Thomas Pohl
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 ******************************************************/

#define CREATE_CREEPS_EXAMPLE( NAME, DX, DY ) \
	printf( "creating example '"NAME"'\n" );  \
	CreEPS eps( NAME, DX, DY );

#ifndef M_PI
#define M_PI  3.14159265358979323846
#endif

using namespace ns_creeps;

int main()
{
	{
	// ArcT
	CREATE_CREEPS_EXAMPLE( "arct.eps", 82, 40 );
	eps.setAttributes( CAtLineThickness(0.5) | CAtTextAlignment(CAt::HCENTER) );
	eps.startPath( 10, 15 );
	eps.addLine( 30, 15 );
	eps.addLine( 25, 35 );
	eps.addMove( 17, 15 );
	eps.addLine( 17, 25 );
	eps.addLine( 27, 28 );
	eps.endPath( CreEPS::STROKE, CAtLineDash(CAt::DASH, 2) );
	eps.startPath( 10, 15 );
	eps.addArcT( 30, 15, 25, 35, 10 );
	eps.endPath( CreEPS::STROKE );
	eps.startPath ( );
	eps.addCircle( 10, 15, 1 );
	eps.addCircle( 30, 15, 1 );
	eps.addCircle( 25, 35, 1 );
	eps.endPath( CreEPS::FILL );
	eps.print( 20, 28, "r" );
	eps.print( 10, 10, "(x0,y0)" );
	eps.print( 30, 10, "(x1,y1)" );
	eps.print( 33, 35, "(x2,y2)", CAtTextAlignment(CAt::CENTER) );
	eps.print( 20, 5, "addArcT" );

	eps.setAttributes( CAtLineThickness(0.5) | CAtTextAlignment(CAt::HCENTER) );
	eps.startPath( 50, 15 );
	eps.addLine( 70, 15 );
	eps.addLine( 65, 35 );
	eps.addMove( 57, 15 );
	eps.addLine( 57, 25 );
	eps.addLine( 67, 28 );
	eps.endPath( CreEPS::STROKE, CAtLineDash(CAt::DASH, 2) );
	eps.startPath( 50, 15 );
	eps.addArcTLine( 70, 15, 65, 35, 10 );
	eps.endPath( CreEPS::STROKE );
	eps.startPath ( );
	eps.addCircle( 50, 15, 1 );
	eps.addCircle( 70, 15, 1 );
	eps.addCircle( 65, 35, 1 );
	eps.endPath( CreEPS::FILL );
	eps.print( 60, 28, "r" );
	eps.print( 50, 10, "(x0,y0)" );
	eps.print( 70, 10, "(x1,y1)" );
	eps.print( 73, 35, "(x2,y2)", CAtTextAlignment(CAt::CENTER) );
	eps.print( 60, 5, "addArcTLine" );
	}
	
	{
	// Fill
	CREATE_CREEPS_EXAMPLE( "fill.eps", 105, 40 );

	eps.setAttributes( CAtLineThickness(2) | CAtLineJoin(CAt::LJ_ROUND) |
	                   CAtTextAlignment(CAt::HCENTER) );
	eps.startPath( 8, 10 );
	eps.addLine( 15, 35 );
	eps.addLine( 22, 10 );
	eps.addLine(  5, 25 );
	eps.addLine( 25, 25 );
	eps.closeSubpath();
	eps.endPath( CreEPS::FILL, CreEPS::STROKE, CAtGrayScale( 0.6 ),
	             CAtGrayScale( 0.0 ));
	eps.print( 15, 5, "(a)" );

	eps.startPath( 33, 10 );
	eps.addLine( 40, 35 );
	eps.addLine( 47, 10 );
	eps.addLine( 30, 25 );
	eps.addLine( 50, 25 );
	eps.closeSubpath();
	eps.endPath( CreEPS::STROKE, CreEPS::FILL, CAtGrayScale( 0.0 ),
	             CAtGrayScale( 0.6 ));
	eps.print( 40, 5, "(b)" );

	eps.startPath( 58, 10 );
	eps.addLine( 65, 35 );
	eps.addLine( 72, 10 );
	eps.addLine( 55, 25 );
	eps.addLine( 75, 25 );
	eps.closeSubpath();
	eps.endPath( CreEPS::EOFILL, CreEPS::STROKE, CAtGrayScale( 0.6 ), CAtGrayScale( 0.0 ));
	eps.print( 65, 5, "(c)" );

	eps.startPath( 83, 10 );
	eps.addLine(  90, 35 );
	eps.addLine(  97, 10 );
	eps.addLine(  80, 25 );
	eps.addLine( 100, 25 );
	eps.closeSubpath();
	eps.endPath( CreEPS::STROKE, CreEPS::EOFILL, CAtGrayScale( 0.0 ), CAtGrayScale( 0.6 ));
	eps.print( 90, 5, "(d)" );
	}

	{
	// Drawing
	const int dx = -75, dy = -40;
	CREATE_CREEPS_EXAMPLE( "drawing.eps", 100, 40-dy );

	eps.setAttributes( CAtLineThickness(0.5) | CAtTextAlignment(CAt::HCENTER) | CAtGrayScale(0) );
	eps.line( 5, 15-dy, 11, 30-dy );
	eps.startPath( );
	eps.addCircle( 5, 15-dy, 1 );
	eps.addCircle( 11, 30-dy, 1 );
	eps.endPath( CreEPS::FILL );
	eps.print( 8, 5-dy, "line");
	eps.print( 6, 11-dy, "x1,y1", CAtTextAlignment(CAt::CENTER) );
	eps.print( 10, 34-dy, "x2,y2", CAtTextAlignment(CAt::CENTER) );

	eps.rectStroke( 22, 15-dy, 14, 7 );
	eps.print( 22, 11-dy, "x,y", CAtTextAlignment(CAt::CENTER) );
	eps.print( 29, 21-dy, "w", CAtTextAlignment(CAt::HCENTER | CAt::TOP) );
	eps.print( 23, 19-dy, "h", CAtTextAlignment(CAt::VCENTER | CAt::LEFT) );
	eps.print( 29, 5-dy, "rectstroke" );
	eps.rectFill( 22, 32-dy, 14, 3 );
	eps.print( 29, 27-dy, "rectfill" );
	eps.startPath( );
	eps.addCircle( 22, 15-dy, 1 );
	eps.addCircle( 22, 32-dy, 1 );
	eps.endPath( CreEPS::FILL );

	eps.startPath( 50, 15-dy );
	eps.addLine( 50, 20-dy );
	eps.addLine( 70, 35-dy );
	eps.addLine( 65, 15-dy );
	eps.endPath( CreEPS::STROKE, CAtLineDash(CAt::DASH, 2) );
	eps.startPath( );
	eps.addCircle( 50, 15-dy, 1 );
	eps.addCircle( 50, 20-dy, 1 );
	eps.addCircle( 70, 35-dy, 1 );
	eps.addCircle( 65, 15-dy, 1 );
	eps.endPath( CreEPS::FILL );
	eps.curve( 50, 15-dy, 50, 20-dy, 70, 35-dy, 65, 15-dy );
	eps.print( 50, 10-dy, "x0,y0", CAtTextAlignment(CAt::CENTER) );
	eps.print( 50, 26-dy, "x1,y1", CAtTextAlignment(CAt::CENTER) );
	eps.print( 62, 35-dy, "x2,y2", CAtTextAlignment(CAt::CENTER) );
	eps.print( 65, 10-dy, "x3,y3", CAtTextAlignment(CAt::CENTER) );
	eps.print( 60,  5-dy, "curve" );

	eps.setAttributes( CAtLineDash(CAt::DASH, 2) );
	eps.startPath( 80, 35-dy );
	eps.addLine( 80, 15-dy );
	eps.addLine( 1/sqrt(2)*20+80, 1/sqrt(2)*20+15-dy );
	eps.endPath( CreEPS::STROKE );
	eps.line( 80, 15-dy, 93, 15-dy );
	eps.arc( 80, 15-dy, 10, 0, 45);
	eps.arc( 80, 15-dy, 12, 0, 90 );
	eps.setAttributes( CAtLineDash(CAt::SOLID, 0) );
	eps.arc( 80, 15-dy, 20, 45, 90 );
	eps.startPath( );
	eps.addCircle( 80, 15-dy, 1 );
	eps.endPath( CreEPS::FILL );
	eps.print( 80, 10-dy, "x,y", CAtTextAlignment(CAt::CENTER) );
	eps.print( 77, 29-dy, "r" );
	eps.print( 87, 17-dy, "a", CAtFont("Symbol", 10) );
	eps.print( 83, 22-dy, "b", CAtFont("Symbol", 10) );
	eps.print( 85,  5-dy, "arc" );

	eps.disk( 110+dx, 25, 1 );
	eps.circle( 110+dx, 25, 10 );
	eps.line( 110+dx, 25, 1/sqrt(2)*10+110+dx, 1/sqrt(2)*10+25, CAtLineDash(CAt::DASH, 2) );
	eps.print( 112+dx, 30, "r" );
	eps.print( 110+dx, 20, "x,y" );
	eps.print( 110+dx, 6, "circle" );

	eps.disk( 135+dx, 25, 1 );
	eps.ellipse( 135+dx, 25, 12, 8, 60 );
	eps.applyTranslation( 135+dx, 25 );
	eps.applyRotation( 60 );
	eps.startPath( 0, 8 );
	eps.addLine( 0, 0 );
	eps.addLine( 12, 0 );
	eps.addMove( 0, 0 );
	eps.resetTransformations();
	eps.addLine( 147+dx, 25 );
	eps.addMove( 142+dx, 25 );
	eps.addArc( 135+dx, 25, 7, 0, 60 );
	eps.endPath( CreEPS::STROKE, CAtLineDash(CAt::DASH, 2) );
	eps.print( 135+dx, 31, "r1" );
	eps.print( 130+dx, 23, "r2" );
	eps.print( 139+dx, 26, "a", CAtFont("Symbol", 10) );
	eps.print( 135+dx, 20, "x,y" );
	eps.print( 135+dx, 6, "ellipse" );
	}

	{
	// Paths
	CREATE_CREEPS_EXAMPLE( "paths.eps", 80, 40 );
	eps.setAttributes( CAtLineThickness(3) | CAtTextAlignment(CAt::HCENTER) );

	eps.startPath( 5, 25 );
	eps.addLine( 10, 15 );
	eps.addLine( 15, 25 );
	eps.closeSubpath();
	eps.addMove( 15, 30 );
	eps.addArc ( 10, 30, 5, 0, 180 );
	eps.closeSubpath();
	eps.endPath(CreEPS::STROKE, CreEPS::FILL, CAtGrayScale(0), CAtGrayScale(0.6));
	eps.print( 10, 5, "(a)" );

	eps.startPath( 35, 25 );
	eps.addLine( 40, 15 );
	eps.addLine( 45, 25 );
	eps.addMove( 45, 30 );
	eps.addArc ( 40, 30, 5, 0, 180 );
	eps.endPath(CreEPS::STROKE, CreEPS::FILL, CAtGrayScale(0), CAtGrayScale(0.6));
	eps.print( 40, 5, "(b)" );

	eps.startPath( 65, 25 );
	eps.addLine( 70, 15 );
	eps.addLine( 75, 25 );
	eps.addLine( 65, 25 );
	eps.addMove( 75, 30 );
	eps.addArc ( 70, 30, 5, 0, 180 );
	eps.addLine( 75, 30 );
	eps.endPath(CreEPS::STROKE, CreEPS::FILL, CAtGrayScale(0), CAtGrayScale(0.6) );
	eps.print( 70, 5, "(c)" );
	}

	{
	// Fill types
	CREATE_CREEPS_EXAMPLE( "filltypes.eps", 105, 40 );
	eps.setAttributes( CAtTextAlignment(CAt::HCENTER) );
	eps.line( 5, 10, 100, 35, CAtLineThickness(2) );
	eps.rectFill( 10, 10, 10, 25, CAtHexDotFilling(0.5, 2) | CAtGrayScale(0.3) | CAtBackgroundColor(0.6, 0.6, 0.6) );
	eps.rectFill( 25, 10, 10, 25, CAtHexDotFilling(0.5, 2) | CAtGrayScale(0.3) );
	eps.print( 22, 5, "HexDotFilling" );
	eps.rectFill( 40, 10, 10, 25, CAtCheckerboardFilling(2, 3) | CAtGrayScale(0.3) | CAtBackgroundColor(0.6, 0.6, 0.6) );
	eps.rectFill( 55, 10, 10, 25, CAtCheckerboardFilling(2, 3) | CAtGrayScale(0.3) );
	eps.print( 52, 5, "CheckerboardFilling" );
	eps.rectFill( 70, 10, 10, 25, CAtStripeFilling(2, 1, -20) | CAtGrayScale(0.3) | CAtBackgroundColor(0.6, 0.6, 0.6) );
	eps.rectFill( 85, 10, 10, 25, CAtStripeFilling(2, 1, -20) | CAtGrayScale(0.3) );
	eps.print( 82, 5, "StripeFilling" );
	}

	
	{ // lines.eps
    CreEPS creeps( "lines.eps", 50, 30 );
    creeps.line( 10, 5, 10, 25 );
    creeps.setAttributes( CAtGrayScale(0.6) | CAtLineThickness(3) );
    creeps.line( 20, 5, 20, 25, CAtGrayScale(0.9) | CAtLineThickness(6) );
    creeps.line( 30, 5, 30, 25 );
    creeps.line( 40, 5, 40, 25, CAtGrayScale(0.3) );
	}
	
	
	{ // linejoin.eps
	CreEPS creeps( "linejoin.eps", 70, 40 );
	CAt::LINEJOIN join[3] = { CAt::MITER,
	                          CAt::LJ_ROUND,
	                          CAt::BEVEL };
	for( int i = 0; i < 3; i++ ) {
	  creeps.startPath( 12 + 15*(i+1), 10 );
	  creeps.addLine(	12 + 15*(i  ), 20 );
	  creeps.addLine(	12 + 15*(i+1), 30 );
	  creeps.endPath( CreEPS::STROKE, CAtLineThickness(6) |
		                                CAtGrayScale(0.7) |
		                                CAtLineJoin(join[i]) );
	  creeps.startPath( 12 + 15*(i+1), 10 );
	  creeps.addLine(	12 + 15*(i  ), 20 );
	  creeps.addLine(	12 + 15*(i+1), 30 );
	  creeps.endPath( CreEPS::STROKE, CAtLineThickness(0.3) );
	}
	creeps.printf( CAtFont("Times-Roman", 10), 17,  3, "MITER" );
	creeps.printf( CAtFont("Times-Roman", 10), 32, 35, "LJ_ROUND" );
	creeps.printf( CAtFont("Times-Roman", 10), 47,  3, "BEVEL" );
	}
	
	
	{ // linecap.eps
	CreEPS creeps( "linecap.eps", 70, 40 );
	creeps.setAttributes( CAtLineThickness(5, CAtGrayScale(0.7)) );
	creeps.line( 15, 15, 15, 30, CAtLineCap(CAt::BUTT) );
	creeps.line( 35, 15, 35, 30, CAtLineCap(CAt::LC_ROUND) );
	creeps.line( 55, 15, 55, 30, CAtLineCap(CAt::SQUARE) );
	creeps.setAttributes( CAtLineThickness(0.3) | CAtGrayScale(0) );
	creeps.line( 15, 15, 15, 30 );
	creeps.line( 35, 15, 35, 30 );
	creeps.line( 55, 15, 55, 30 );
	creeps.setAttributes( CAtFont("Times-Roman", 10) |
	                      CAtTextAlignment(CAt::HCENTER) );
	creeps.printf( 15, 6, "BUTT" );
	creeps.printf( 35, 6, "LC_ROUND" );
	creeps.printf( 55, 6, "SQUARE" );
	}
	
	
	{ // linedash01.eps
	CreEPS creeps( "linedash01.eps", 45, 10 );
	creeps.line( 5, 5, 40, 5, CAtLineDash("2 2 1 2", 0) );
	}

	{ // linedash02.eps
	CreEPS creeps( "linedash02.eps", 45, 10 );
	creeps.line( 5, 5, 40, 5, CAtLineDash("2 2 1", 0) );
	}
	
	{ // linedash03.eps
	CreEPS creeps( "linedash03.eps", 45, 10 );
	creeps.line( 5, 7, 40, 7, CAtLineDash("4 3 2 1", 0) );
	creeps.line( 5, 3, 40, 3, CAtLineDash("4 3 2 1", 3) );
	}
	
	{ // linedash04.eps
	CreEPS creeps( "linedash04.eps", 50, 40 );
	for( int i = 1; i < 4; i++ )
		creeps.line( 5, 40-10*i, 45, 40-10*i, CAtLineDash(CAt::DOT, 0) |
		                                      CAtLineThickness(2*i)      );
	}

	{ // linedash05.eps
	CreEPS creeps( "linedash05.eps", 85, 40 );
	creeps.setAttributes( CAtFont("Times-Roman", 10) |
	                      CAtLineThickness(4) |
	                      CAtTextAlignment(CAt::VCENTER | CAt::LEFT) );
	creeps.printf( 5, 30, "DOT" );
	creeps.printf( 5, 20, "DASH" );
	creeps.printf( 5, 10, "DOTDASH" );

	creeps.line( 30, 30, 80, 30, CAtLineDash(CAt::DOT,	2) );
	creeps.line( 30, 20, 80, 20, CAtLineDash(CAt::DASH,	 2) );
	creeps.line( 30, 10, 80, 10, CAtLineDash(CAt::DOTDASH, 4) );

	creeps.setAttributes( CAtFont(9) );
	creeps.printf( 30, 26, " T" );
	creeps.printf( 36, 26, "xT" );
	creeps.printf( 42, 26, " T" );
	creeps.printf( 48, 26, "xT" );
	creeps.printf( 54, 26, " T" );
	creeps.printf( 60, 26, "xT" );
	creeps.printf( 66, 26, " T" );

	creeps.printf( 32, 16, "xT" );
	creeps.printf( 40, 16, "xT" );
	creeps.printf( 48, 16, "xT" );
	creeps.printf( 56, 16, "xT" );
	creeps.printf( 64, 16, "xT" );
	creeps.printf( 72, 16, "xT" );

	creeps.printf( 30,  6, " T" );
	creeps.printf( 35,  6, "xT/2" );
	creeps.printf( 48,  6, "xT" );
	creeps.printf( 59,  6, "xT/2" );
	creeps.printf( 66,  6, " T" );
	}


	{ // linedash06.eps
	CreEPS creeps( "linedash06.eps", 50, 25 );
   creeps.setAttributes( CAtLineThickness(1) |
	                      CAtLineCap(CAt::LC_ROUND) |
	                      CAtLineDash(CAt::DOT, 1)    );
  creeps.line( 5, 20, 45, 20 );
  creeps.line( 5, 15, 45, 15, CAtLineThickness(2) );
  creeps.setAttributes( CAtLineCap(CAt::BUTT) );
  creeps.line( 5, 10, 45, 10 );  // THIS LINE STAYS INVISIBLE !!
  creeps.line( 5,  5, 45,  5, CAtLineDash(CAt::DOT, 1) );
	}


	{ // fonts.eps
	CreEPS creeps( "fonts.eps", 125, 27 );
	creeps.setAttributes( CAtFont(10));
	creeps.printf( CAtFont("Times-Roman"),            5, 20, "Times-Roman" );
	creeps.printf( CAtFont("Times-Italic"),           5, 15, "Times-Italic" );
	creeps.printf( CAtFont("Times-Bold"),             5, 10, "Times-Bold" );
	creeps.printf( CAtFont("Times-BoldItalic"),       5,  5, "Times-BoldItalic" );
	creeps.printf( CAtFont("Helvetica"),             35, 20, "Helvetica" );
	creeps.printf( CAtFont("Helvetica-Oblique"),     35, 15, "Helvetica-Oblique" );
	creeps.printf( CAtFont("Helvetica-Bold"),        35, 10, "Helvetica-Bold" );
	creeps.printf( CAtFont("Helvetica-BoldOblique"), 35,  5, "Helvetica-BoldOblique" );
	creeps.printf( CAtFont("Courier"),               78, 20, "Courier" );
	creeps.printf( CAtFont("Courier-Oblique"),       78, 15, "Courier-Oblique" );
	creeps.printf( CAtFont("Courier-Bold"),          78, 10, "Courier-Bold" );
	creeps.printf( CAtFont("Courier-BoldOblique"),   78,  5, "Courier-BoldOblique" );
	}


	{ // align.eps
	CreEPS creeps( "align.eps", 85, 40 );
	int x = 30, y = 14;
	creeps.setAttributes( CAtLineThickness(0.2) |
	                      CAtLineDash(CAt::DASH, 2) |
	                      CAtFont("Times-Roman") );
	creeps.printf( CAtFont(50) | CAtTextAlignment(CAt::LEFT | CAt::BOTTOM),
	               x, y, "align" );
	creeps.line( x -	  4, y +   16, x + 35.5 + 4, y +   16 );
	creeps.line( x -	  4, y +  3.5, x + 35.5 + 4, y +  3.5 );
	creeps.line( x -	  4, y  	 , x + 35.5 + 4, y  	  );
	creeps.line( x  	   , y +   20, x		   , y -	4 );
	creeps.line( x +   35.5, y +   20, x + 35.5    , y -	4 );
	creeps.line( x + 35.5/2, y +   20, x + 35.5/2  , y -	4 );
	creeps.line( x -	  4, y + 16/2, x + 35.5 + 4, y + 16/2 );
	creeps.setAttributes( CAtFont(10) | CAtTextAlignment(CAt::RIGHT | CAt::VCENTER) );
	creeps.printf( x - 5, y, "BOTTOM" );
	creeps.printf( x - 5, y + 3.5, "BASELINE" );
	creeps.printf( x - 5, y + 16/2, "VCENTER" );
	creeps.printf( x - 5, y + 16, "TOP" );
	creeps.setAttributes( CAtTextAlignment( CAt::HCENTER | CAt::TOP	));
	creeps.printf( x		 , y - 5, "LEFT" );
	creeps.printf( x + 35.5/2, y - 5, "HCENTER" );
	creeps.printf( x + 35.5  , y - 5, "RIGHT" );
	}


	{
	// Pitfalls
	CREATE_CREEPS_EXAMPLE( "pitfalls.eps", 110, 40 );
	eps.rectFill( 5, 5, 40, 30, CAtHexDotFilling(0.5,2) | CAtColor(1,0,0) | CAtBackgroundColor(0,0,1) );
	eps.setAttributes( CAtFont("Helvetica-Bold", 12) | CAtTextAlignment(CAtTextAlignment::CENTER) | CAtGrayScale(1) );
	eps.print( 25, 25, "Blue background" );
	eps.print( 25, 15, "Red dots" );

	eps.setAttributes( CAtGrayScale(0) );	
	eps.print( 78, 20, "Striped?", CAtStripeFilling(1,2,30) | CAtColor(1,1,0) | CAtBackgroundColor(1,0,1) | CAtFont("Helvetica-Bold", 40) );
	eps.line( 50, 12, 107, 12, CAtLineThickness(2) | CAtStripeFilling(1,2,30) | CAtColor(1,1,0) | CAtBackgroundColor(1,0,1) );
	}

	{
	// Interpreter info
	CREATE_CREEPS_EXAMPLE( "info.eps", 80, 31 );

	eps.setAttributes( CAtFont("Times-Roman", 12) |
	                   CAtTextAlignment(CAt::DEFAULT) |
	                   CAtGrayScale(0) );
	eps.special( "/str 20 string def\n" );
	eps.special( "product 5 23 moveto (Product: ) show show\n" );
	eps.special( "version 5 17 moveto (Version: ) show show\n" );
	eps.special( "revision str cvs 5 11 moveto (Revision: ) show show\n" );
	eps.special( "languagelevel str cvs 5 5 moveto (Language level: ) show show\n" );
	}

	{
	// Transformations
	CREATE_CREEPS_EXAMPLE( "transformations.eps", 120, 40 );

	eps.setAttributes( CAtLineThickness(2) |
	                   CAtLineJoin(CAt::LJ_ROUND) |
	                   CAtTextAlignment(CAt::HCENTER) );

	eps.applyTranslation( 30, 20 );
	eps.applyRotation( 5 );
	eps.applyScaling( 2.5, 1 );
	eps.startPath( -7, -10 );
	eps.addLine( 0, 15 );
	eps.addLine( 7, -10 );
	eps.addLine( -10, 5 );
	eps.addLine( 10, 5 );
	eps.closeSubpath();
	eps.resetTransformations();
	eps.endPath( CreEPS::FILL, CreEPS::STROKE,
	             CAtStripeFilling(2, 1, 90) | CAtGrayScale(0.3) | CAtBackgroundColor(0.6, 0.6, 0.6),
	             CAtGrayScale( 0.0 ));
	eps.print( 30, 5, "(a)" );

	eps.applyTranslation( 90, 20 );
	eps.applyRotation( 5 );
	eps.applyScaling( 2.5, 1 );
	eps.startPath( -7, -10 );
	eps.addLine( 0, 15 );
	eps.addLine( 7, -10 );
	eps.addLine( -10, 5 );
	eps.addLine( 10, 5 );
	eps.closeSubpath();
	eps.endPath( CreEPS::FILL, CreEPS::STROKE,
	             CAtStripeFilling(2, 1, 90) | CAtGrayScale(0.3) | CAtBackgroundColor(0.6, 0.6, 0.6),
	             CAtGrayScale( 0.0 ));
	eps.resetTransformations();
	eps.print( 90, 5, "(b)" );
	}	

	{
	// Rotating text
	CREATE_CREEPS_EXAMPLE( "rotext.eps", 40, 40 );
	eps.setAttributes( CAtFont(25) | CAtTextAlignment(CAt::RIGHT | CAt::TOP) );

	for (int alpha = 0; alpha < 360; alpha += 60)
		eps.print( 20, 20, alpha, "mrgl" );
	eps.rectFill( 19.5, 19.5, 1, 1, CAtColor(1, 0, 0) );
	}

	{
	// Tricks with usePath
	CREATE_CREEPS_EXAMPLE( "usepath.eps", 70, 40 );
	eps.setAttributes( CAtLineJoin(CAt::LJ_ROUND) );
	eps.startPath( 13, 8 );
	eps.addLine( 20, 33 );
	eps.addLine( 27,  8 );
	eps.addLine( 10, 23 );
	eps.addLine( 30, 23 );
	eps.closeSubpath();
	for (int i = 10; i >= 0; i--)
		eps.usePath( CreEPS::STROKE,
		             CAtGrayScale( i/11.0, CAtLineThickness( i+0.5 )));
	eps.endPath();

	eps.setAttributes( CAtLineCap(CAt::LC_ROUND) );
	eps.startPath( 45, 35 );
	eps.addLine( 45, 10 );
	eps.usePath( CreEPS::STROKE, CAtGrayScale(0.8) | CAtLineThickness(6) );
	eps.addLine( 65, 30 );
	eps.usePath( CreEPS::STROKE, CAtGrayScale(0.5) | CAtLineThickness(4) );
	eps.addLine( 65,  5 );
	eps.endPath( CreEPS::STROKE, CAtGrayScale(0.2) | CAtLineThickness(2) );
	}
	
	{
	// CreEPS
	CREATE_CREEPS_EXAMPLE( "creeps.eps", 100, 40 );
	eps.setAttributes( CAtLineThickness( 4 ) );
	eps.startPath();
	eps.addArc( 20, 20, 10, 90, 270 );
	eps.addArcN( 30, 10, 10, 180, 90 );
	eps.addLine( 40, 20 );
	eps.addMove( 50, 20 );
	eps.addLine( 60, 20 );
	eps.addMove( 40, 30 );
	eps.addArc( 40, 20, 10, 90, 270 );
	eps.addCircle( 60, 20, 10 );
	eps.addMove( 60, 30 );
	eps.addLine( 60,  4 );
	eps.addMove( 80, 10 );
	eps.addArc( 80, 20, 10, 270, 90 );
	eps.addArcN( 80, 32.5, 2.5, 270, 90 );
	eps.endPath( CreEPS::STROKE );
	}

	{
	// CreEPS
	CREATE_CREEPS_EXAMPLE( "embedeps.eps", 85, 40 );
	eps.applyScaling( 3.0/2.0, 3.0/2.0 );
	eps.embedEPS( "lines.eps" );
	eps.applyScaling( 2.0/3.0, 2.0/3.0 );
	eps.embedEPS( "align.eps" );
	eps.embedEPS( "lines.eps" );
	}
	
	return 0;
}
